@@ -298,9 +298,6 @@ public:
                                        bool reverse,
                                        int progress) const;
 
-    //* scrollbar groove
-    void renderScrollBarGroove(QPainter *painter, const QRect &rect, const QColor &color) const;
-
     //* scrollbar handle
     void renderScrollBarHandle(QPainter *, const QRectF &, const QColor &fg, const QColor &bg) const;
 
